@@ -24,26 +24,17 @@
 
 #include "seahorse-cleanup.h"
 #include "seahorse-context.h"
-#include "seahorse-gtkstock.h"
+#include "seahorse-icons.h"
 #include "seahorse-registry.h"
 #include "seahorse-secure-memory.h"
 #include "seahorse-util.h"
 
 #include "seahorse-key-manager.h"
 
-#ifdef WITH_PGP
-#include "pgp/seahorse-pgp-module.h"
-#endif
-
-#ifdef WITH_SSH
-#include "ssh/seahorse-ssh-module.h"
-#endif
-
-#ifdef WITH_PKCS11
-#include "pkcs11/seahorse-pkcs11-module.h"
-#endif
-
-#include "gkr/seahorse-gkr-module.h"
+#include "gkr/seahorse-gkr.h"
+#include "pgp/seahorse-pgp.h"
+#include "ssh/seahorse-ssh.h"
+#include "pkcs11/seahorse-pkcs11.h"
 
 #include <locale.h>
 #include <stdlib.h>
@@ -56,6 +47,9 @@ static gboolean show_version = FALSE;
 int
 main (int argc, char **argv)
 {
+	SeahorseWidget *swidget;
+	SeahorseContext *context;
+
     static GOptionEntry options[] = {
         { "version", 'v', 0, G_OPTION_ARG_NONE, &show_version, N_("Version of this application"), NULL },
         { NULL, 0, 0, 0, NULL, NULL, NULL }
@@ -63,8 +57,6 @@ main (int argc, char **argv)
     GError *error = NULL;
     int ret = 0;
 
-    g_thread_init (NULL);
-
     seahorse_secure_memory_init ();
     
 #ifdef ENABLE_NLS
@@ -86,33 +78,29 @@ main (int argc, char **argv)
     }
 
     /* Insert Icons into Stock */ 
-    seahorse_gtkstock_init ();
-    
+    seahorse_icons_init ();
+
     /* Make the default SeahorseContext */
     seahorse_context_create ();
+    context = seahorse_context_instance ();
 
     /* Initialize the various components */
-#ifdef WITH_PGP
-    seahorse_pgp_module_init ();
-#endif
-#ifdef WITH_SSH
-    seahorse_ssh_module_init ();
-#endif
-#ifdef WITH_PKCS11
-    seahorse_pkcs11_module_init ();
-#endif
-    seahorse_gkr_module_init ();
+    seahorse_pgp_backend_initialize ();
+    seahorse_ssh_backend_initialize ();
+    seahorse_pkcs11_backend_initialize ();
+    seahorse_gkr_backend_initialize ();
 
-    seahorse_key_manager_show ();
+    swidget = seahorse_key_manager_show ();
 
-    /* Start the refreshing of the keys */
-    seahorse_context_refresh_auto (NULL);
+    g_object_ref (context);
+    g_signal_connect_after (context, "destroy", gtk_main_quit, NULL);
 
-    g_signal_connect_after (SCTX_APP (), "destroy", gtk_main_quit, NULL);
-    
     gtk_main ();
 
-
     seahorse_cleanup_perform ();
+
+    g_object_unref (swidget);
+    g_object_unref (context);
+
     return ret;
 }
